@@ -8,8 +8,8 @@ ND <- function(web, normalised=TRUE){
     dhigher <- colSums(web)  
     Nlow <- Nhigh <- 2 # effectively unnormalised
     if (normalised){
-      Nlow <- length(dlower)
-      Nhigh <- length(dhigher)
+      Nlow <- length(dhigher)+1
+      Nhigh <- length(dlower)+1
     }
     low <- dlower/(Nlow-1); names(low) <- rownames(web)
     high <- dhigher/(Nhigh-1); names(high) <- colnames(web)
@@ -23,7 +23,7 @@ CC <- function(web, cmode="suminvdir", rescale=TRUE, ...){
     # ... options passed on to closeness in package sna
     # uses a version to calculate centrality that allows for disconnected graphs
     w <- as.one.mode(web)
-    cc <- closeness(w, cmode=cmode, rescale=rescale, ...)
+    cc <- sna::closeness(w, cmode=cmode, rescale=rescale, ...)
     low <- cc[1:nrow(web)]; names(low) <- rownames(web)
     high <- cc[(nrow(web)+1):length(cc)]; names(high) <- colnames(web)
     list("lower"=low, "higher"=high)
@@ -35,7 +35,7 @@ BC <- function(web, rescale=TRUE, ...){
     # by Carsten F. Dormann, 14 Dec 2010
     # ... options passed on to closeness in package sna; particularly: rescale=TRUE!
     w <- as.one.mode(web)
-    bc <- betweenness(w, rescale=rescale, ...)
+    bc <- sna::betweenness(w, rescale=rescale, ...)
     low <- bc[1:nrow(web)]; names(low) <- rownames(web)
     high <- bc[(nrow(web)+1):length(bc)]; names(high) <- colnames(web)
     list("lower"=low, "higher"=high)
@@ -51,7 +51,6 @@ BC <- function(web, rescale=TRUE, ...){
 #(cci <- CC(olesen2002flores))
 #(bci <- BC(olesen2002flores))
 #
-#
 #cor.test(bci[[1]], ndi[[1]], method="spear") # 0.779
 #cor.test(cci[[1]], ndi[[1]], method="spear") # 0.826
 #
@@ -67,29 +66,12 @@ BC <- function(web, rescale=TRUE, ...){
 #summary(nls(cc ~ c*nd^d, start=list(c=0.02,d=2))) 
 ## BC:
 #summary(nls(bc ~ a*nd+b, start=list(a=1,b=1)))
-#summary(nls(bc ~ c*nd^d, start=list(c=-0.02,d=2))) # lower RSE
+#summary(nls(bc ~ c*nd^d, start=list(c=0.02,d=2))) # lower RSE
 #
 ### ANIMALS:
 #bc <- bci[[2]]
 #cc <- cci[[2]]
 #nd <- ndi[[2]]
-#
-#plot(bc ~ nd)
-#lognd <- log(nd)
-#newx <- seq(min(log(nd)), max(log(nd)), length=10)
-#
-#fm <- lm(log(bc) ~ lognd)
-#plot(log(bc) ~ log(nd))
-#preds <- predict(fm, interval="confidence", newdata=data.frame(lognd=newx))
-#matlines(newx, preds, col=c("black", "grey", "grey"), lty=1)
-#cbind(obs=log(bc), predict(fm, interval="confidence")[,c(2,3)])
-## outside the 95% CI:
-#out <- which(log(bc) > predict(fm, interval="confidence")[,c(3)] | log(bc) < predict(fm, interval="confidence")[,c(2)])
-## now fit a straight line:
-#straight <- lm(bc[-out] ~ nd[-out]) # y = mx+b; y=0 --> x = -b/m
-#(xintercept <- -coef(straight)[1]/coef(straight)[2])
-#
-
 ## CC:
 #summary(nls(cc ~ a*nd+b, start=list(a=1,b=1))) 
 #summary(nls(cc ~ c*nd^d, start=list(c=0.2,d=2))) # lower RSE
@@ -100,6 +82,4 @@ BC <- function(web, rescale=TRUE, ...){
 #
 ##see also, for whole web measures:
 #centralization(web, "degree")
-#centralization(web, "betweenness")
-
-
+#centralization(web, "betweenness")
\ No newline at end of file
